Skip to contents

Returns the NBM codes table with descriptions. NBM was the nomenclature used in Brazil before NCM adoption and is used only for historical data (1989-1996).

Usage

comex_nbm(language = "en", verbose = FALSE)

Arguments

language

Language: "pt", "en", or "es". Default: "en"

verbose

Logical. If TRUE, display progress messages. Default: FALSE

Value

A tibble with NBM codes and descriptions

Examples

if (FALSE) { # \dontrun{
comex_nbm()
} # }