powered by
Returns the NBM codes table with descriptions. NBM was the nomenclature used in Brazil before NCM adoption and is used only for historical data (1989-1996).
comex_nbm( language = "en", search = NULL, add = NULL, page = NULL, per_page = NULL, verbose = FALSE )
A data.frame with NBM codes and descriptions.
Language: "pt", "en", or "es". Default: "en".
"pt"
"en"
"es"
Optional search term to filter results.
Optional related table to include (e.g. "ncm").
"ncm"
Page number for pagination. Default: NULL.
NULL
Number of results per page. Default: NULL.
Logical. Default: FALSE.
FALSE
if (FALSE) { comex_nbm() comex_nbm(search = "encomendas", per_page = 5) comex_nbm(add = "ncm") }
Run the code above in your browser using DataLab